@@ -2,6 +2,7 @@
 #'
 #' @name mlr_learners_clust.featureless
 #' @include LearnerClust.R
+#' @include aaa.R
 #'
 #' @description
 #' A simple [LearnerClust] which randomly (but evenly) assigns observations to
@@ -28,6 +29,7 @@ LearnerClustFeatureless = R6Class("LearnerClustFeatureless",
         predict_types = c("partition", "prob"),
         param_set = ps,
         properties = c("partitional", "exclusive", "complete", "missings"),
+        man = "mlr3cluster::mlr_learners_clust.featureless",
         label = "Featureless Clustering"
       )
     }
@@ -80,3 +82,5 @@ LearnerClustFeatureless = R6Class("LearnerClustFeatureless",
     }
   )
 )
+
+learners[["clust.featureless"]] = LearnerClustFeatureless
