@@ -2,6 +2,7 @@
 #'
 #' @name mlr_learners_clust.kkmeans
 #' @include LearnerClust.R
+#' @include aaa.R
 #'
 #' @description
 #' A [LearnerClust] for kernel k-means clustering implemented in [kernlab::kkmeans()].
@@ -63,6 +64,7 @@ LearnerClustKKMeans = R6Class("LearnerClustKKMeans",
         param_set = ps,
         properties = c("partitional", "exclusive", "complete"),
         packages = "kernlab",
+        man = "mlr3cluster::mlr_learners_clust.kkmeans",
         label = "Kernel K-Means"
       )
     }
@@ -101,3 +103,5 @@ LearnerClustKKMeans = R6Class("LearnerClustKKMeans",
     }
   )
 )
+
+learners[["clust.kkmeans"]] = LearnerClustKKMeans
