@@ -1,7 +1,8 @@
 #' @title Mini Batch K-Means Clustering Learner
 #'
-#' @name mlr_learners_clust.MiniBatchKMeans
+#' @name mlr_learners_clust.MBatchKMeans
 #' @include LearnerClust.R
+#' @include aaa.R
 #'
 #' @description
 #' A [LearnerClust] for mini batch k-means clustering implemented in [ClusterR::MiniBatchKmeans()].
@@ -48,6 +49,7 @@ LearnerClustMiniBatchKMeans = R6Class("LearnerClustMiniBatchKMeans",
         param_set = ps,
         properties = c("partitional", "fuzzy", "exclusive", "complete"),
         packages = "ClusterR",
+        man = "mlr3cluster::mlr_learners_clust.MBatchKMeans",
         label = "Mini Batch K-Means"
       )
     }
@@ -97,3 +99,5 @@ LearnerClustMiniBatchKMeans = R6Class("LearnerClustMiniBatchKMeans",
     }
   )
 )
+
+learners[["clust.MBatchKMeans"]] = LearnerClustMiniBatchKMeans
