@@ -2,6 +2,7 @@
 #'
 #' @name mlr_learners_clust.pam
 #' @include LearnerClust.R
+#' @include aaa.R
 #'
 #' @description
 #' A [LearnerClust] for PAM clustering implemented in [cluster::pam()].
@@ -50,6 +51,7 @@ LearnerClustPAM = R6Class("LearnerClustPAM",
         param_set = ps,
         properties = c("partitional", "exclusive", "complete"),
         packages = "cluster",
+        man = "mlr3cluster::mlr_learners_clust.pam",
         label = "Partitioning Around Medoids"
       )
     }
@@ -85,3 +87,5 @@ LearnerClustPAM = R6Class("LearnerClustPAM",
     }
   )
 )
+
+learners[["clust.pam"]] = LearnerClustPAM
