@@ -12,7 +12,7 @@ registerS3method("generate_tasks", "LearnerClust", generate_tasks.LearnerClust,
 )
 
 sanity_check.PredictionClust = function(prediction, task, ...) { # nolint
-  prediction$score(measures = msr("clust.silhouette"), task = task) > 0
+  prediction$score(measures = msr("clust.silhouette"), task = task) > -1L
 }
 registerS3method("sanity_check", "PredictionClust", sanity_check.PredictionClust,
   envir = parent.frame()
